ntrfc package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ntrfc.cascade_case
   ntrfc.dictutils
   ntrfc.filehandling
   ntrfc.fluid
   ntrfc.geometry
   ntrfc.math
   ntrfc.meshquality
   ntrfc.timeseries
   ntrfc.turbo

Submodules
----------

ntrfc.ntrfc module
------------------

.. automodule:: ntrfc.ntrfc
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc
   :members:
   :undoc-members:
   :show-inheritance:
